#
# spec file for package tcpflow
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2011 Sebastien Braun.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           tcpflow
Version:        1.6.1
Release:        2.16
Summary:        Program for capturing and collecting TCP streams
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Diagnostic
URL:            https://github.com/simsong/tcpflow
Source:         https://www.digitalcorpora.org/downloads/tcpflow/%{name}-%{version}.tar.gz

%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  gcc-c++
BuildRequires:  libpcap-devel
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)

%description
tcpflow is a program that captures data transmitted as part of TCP connections
(flows), and stores the data in a way that is convenient for protocol
analysis and debugging. Each TCP flow is stored in its own file. Thus, the
typical TCP flow will be stored in two files, one for each direction.
tcpflow can also process stored 'tcpdump' packet flows.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(0644,root,root)
%license COPYING
%doc AUTHORS NEWS TODO.txt ChangeLog
%attr(0755,root,root) %{_bindir}/tcpflow
%{_mandir}/man1/*.1.*

%changelog
* Tue Apr 12 2022 Marcus Meissner <meissner@suse.com>
- https urls
* Sat Feb 20 2021 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.6.1:
  - Here is release v1.6.1. Does not use the new be13 API that is updated for C++17. That's coming.
  - Some problems with the checks, but they are problems with the test harness, not the tests themselves. Help from volunteers is appreciated!
- No changelog for version 1.6.0 available.
- Update to version 1.5.2:
  - fixed sizeof(addr1) and sizeof(addr2) error in un_pair
- Update to version 1.5.1:
  - updated for pcap_findalldevs
  - added -Wno-address-of-packed-member to avoid error
* Mon May 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add the missing zlib requirement.
* Wed Oct 10 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Tue Oct  9 2018 Cristian Rodríguez <crrodriguez@opensuse.org>
- Update to version 1.5.0
  + Supports openssl 1.1
  + option for setting the libpcap update timeout
* Fri Feb 16 2018 dimstar@opensuse.org
- Update to version 1.4.5:
  + Handles RFC1122 keepalive packets.
  + Fixed wifi selection and added wifi viz.
  + New option -0 to omit extra new lines.
  + Various build fixes.
- Replace openssl-devel BuildRequires with pkgconfig(openssl),
  limited to versions < 1.1: tcpflow is not yet compatible to
  openssl-1.1.
- Package COPYING as license, not as doc.
* Thu Feb  2 2017 adam.majer@suse.de
- use individual libboost-*-devel packages instead of boost-devel
* Tue Mar 31 2015 p.drouand@gmail.com
- Update to version 1.4.4
  * The ChangeLog/NEWS file has not been updated for this release
- Use the download Url provided by upstream
- Add openssl-devel and boost-devel build require; new upstream dependency
* Fri Aug 24 2012 cfarrell@suse.com
- license update: GPL-3.0+
  Source code files state that they are ^GPL^ licensed and to refer back to
  the ^LICENSE^ file for details. There is no ^LICENSE^ file but there is a
  ^COPYING^ file and that is clearly GPL-3.0
* Wed Aug 22 2012 Greg.Freemyer@gmail.com
  Upgrade to v1.3.0
  - converted code from c to c++
  * various fixes and additional features
  * src/tcpip.cpp (tcpip::close_file): added support for FUTIMENS, but I don't yet have a system on which to test it. Hope that it's good.
  * src/main.cpp (main): -r option now allows for multiple files to be specified.
  * src/main.cpp (main): -R option now allows for incomplete tcp connections to be finished.
  * src/tcpip.cpp (tcpdemux::tcpdemux): default outdir is now "."
  * src/xml.cpp (xml::add_cpuid): better handling of CPUID instruction. Now it really should not show up on non-Intel architectures.
  * src/main.cpp (main): added printing stats for debug level 3.
  * src/tcpip.cpp (tcpdemux::close_all): Jeremey's FD ring has been replaced with an unordere dset.
  * COPYING: updated to GPLv3
  * src/flow.cpp (flow::filename): completely rewrote to support templates.
  (flow::print_usage): added to give information on templates.
  * src/main.cpp (main): fixed option parsing bug.
  (class ipaddr): created class for IP addresses
  (class flow_state_struct): created class from struct
  * src/main.cpp (print_usage): -X added for XML output.
  * src/main.cpp (main): changed bytes_per_flow from int to uint64_t
  progname is now a global.
  * src/main.cpp (main): added -B option to force binary output.
  * src/util.cpp: removed copy_argv(); replaced with a simple std::string manipulation.
  (flow_filename): modified to work with outdir
  * src/tcpip.c (print_packet): modified to respect bytes_per_flow
  * src/main.c (main): removed prepending of (ip or ip6 or vlan) from user expressions. We now just use what the user provided.
* Sun Dec 18 2011 sebastien@sebbraun.de
- Initial packaging attempt
